@@ -35,7 +35,7 @@ curl -fsSL https://download.docker.com/linux/ubuntu/gpg | apt-key add -
 curl -fsSL https://download.bell-sw.com/pki/GPG-KEY-bellsoft | apt-key add -
 apt-get update
 set +e && apt-get purge -y google-cloud-sdk lxc-docker && set -e
-apt-get install -y --no-install-recommends \
+DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
     aptitude \
     ca-certificates \
     cgroupfs-mount \
@@ -52,12 +52,15 @@ apt-get install -y --no-install-recommends \
     python3 \
     python3-pip \
     rsync \
+    tcl \
     tmux \
     unzip \
     vim
 
 cp -R /etc/alternatives /etc/keep-alternatives
 apt-get install -y --no-install-recommends \
+    openjdk-8-jdk \
+    openjdk-11-jdk \
     bellsoft-java11 \
     bellsoft-java8
 rm -rf /etc/alternatives
