@@ -70,8 +70,10 @@ fi
 set -e
 set -x
 
-CONCOURSE_SCHEME=https
-CONCOURSE_URL=${CONCOURSE_SCHEME}://${CONCOURSE_HOST}
+if [[ "${CONCOURSE_HOST}" == "concourse.apachegeode-ci.info" ]]; then
+  CONCOURSE_SCHEME=https
+fi
+CONCOURSE_URL=${CONCOURSE_SCHEME:-"http"}://${CONCOURSE_HOST}
 FLY_TARGET=${CONCOURSE_HOST}-${CONCOURSE_TEAM}
 
 . ${SCRIPTDIR}/../shared/utilities.sh
@@ -128,16 +130,16 @@ YML
     echo "Target ${FLY_TARGET} already exists."
   fi
 
+  FLY=${FLY:-$(which fly)}
 
   set -e
-  if [[ "${UPSTREAM_FORK}" != "apache" ]]; then
+  if [[ ${UPSTREAM_FORK} != "apache" ]]; then
     ${FLY} -t ${FLY_TARGET} status || \
     ${FLY} -t ${FLY_TARGET} login \
            --team-name ${CONCOURSE_TEAM} \
            --concourse-url=${CONCOURSE_URL}
   fi
 
-  ${FLY} -t ${FLY_TARGET} sync
   ${FLY} -t ${FLY_TARGET} set-pipeline \
     -p ${META_PIPELINE} \
     --config ${SCRIPTDIR}/generated-pipeline.yml \
@@ -276,14 +278,15 @@ set +x
 
 if [[ "${GEODE_FORK}" != "${UPSTREAM_FORK}" ]]; then
   echo "Disabling unnecessary jobs for forks."
-  pauseJobs ${META_PIPELINE} set-reaper-pipeline
+  pauseJobs ${META_PIPELINE} set-reaper-pipeline set-mass-test-run-pipeline
 elif [[ "$GEODE_FORK" == "${UPSTREAM_FORK}" ]] && [[ "$GEODE_BRANCH" == "develop" ]]; then
   echo "Disabling optional jobs for develop"
+  pauseJobs ${META_PIPELINE} set-mass-test-run-pipeline
   pauseNewJobs ${META_PIPELINE} set-pr-pipeline set-examples-pipeline
 else
   echo "Disabling unnecessary jobs for support branches."
   echo "*** DO NOT RE-ENABLE THESE META-JOBS ***"
-  pauseJobs ${META_PIPELINE} set-images-pipeline set-reaper-pipeline
+  pauseJobs ${META_PIPELINE} set-images-pipeline set-reaper-pipeline set-mass-test-run-pipeline
   pauseNewJobs ${META_PIPELINE} set-pr-pipeline set-examples-pipeline
 fi
 
@@ -303,6 +306,7 @@ if [[ "$GEODE_FORK" == "${UPSTREAM_FORK}" ]]; then
   fi
   if [[ "$GEODE_BRANCH" == "develop" ]]; then
     enableFeature pr
+    enableFeature mass-test-run
   fi
 fi
 
