@@ -15,6 +15,7 @@
 
 package org.apache.geode.rest.internal.web;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.IOException;
@@ -65,7 +66,7 @@ public class RestRegionAPIDUnitTest {
   }
 
   private <K, V> Region<K, V> getRegionA() {
-    return server.getCache().getRegion("/regionA");
+    return server.getCache().getRegion(SEPARATOR + "regionA");
   }
 
   public static GeodeDevRestClient restClient;
@@ -183,7 +184,7 @@ public class RestRegionAPIDUnitTest {
 
   @Test
   public void putWithCAS() {
-    Region<?, ?> region = server.getCache().getRegion("/regionA");
+    Region<?, ?> region = server.getCache().getRegion(SEPARATOR + "regionA");
     // do a regular put first
     restClient.doPutAndAssert("/regionA/customer1",
         "{\"customerId\":1,\"firstName\":\"jon\",\"lastName\":\"doe\"}")
@@ -267,7 +268,8 @@ public class RestRegionAPIDUnitTest {
 
     String urlPrefix =
         "/queries/adhoc?q=" + URLEncoder.encode(
-            "SELECT book.displayprice FROM /regionA e, e.store.book book  WHERE book.displayprice > 5",
+            "SELECT book.displayprice FROM " + SEPARATOR
+                + "regionA e, e.store.book book  WHERE book.displayprice > 5",
             "UTF-8");
 
     restClient.doGetAndAssert(urlPrefix).statusIsOk().hasJsonArrayOfDoubles().hasSize(12)
@@ -284,7 +286,8 @@ public class RestRegionAPIDUnitTest {
     // create 5 prepared statements
     for (int i = 0; i < 5; i++) {
       String urlPrefix = "/queries/?id=" + "Query" + i + "&q=" + URLEncoder.encode(
-          "SELECT book.displayprice FROM /regionA e, e.store.book book  WHERE book.displayprice > $1",
+          "SELECT book.displayprice FROM " + SEPARATOR
+              + "regionA e, e.store.book book  WHERE book.displayprice > $1",
           "UTF-8");
       restClient.doPostAndAssert(urlPrefix, "").statusIsOk();
     }
