@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.internal.index;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.cache.RegionShortcut.PARTITION;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
@@ -70,8 +71,7 @@ public class IndexManagerIntegrationTest {
     TestQueryObject.throwException = false;
 
     logFile = temporaryFolder.newFile(testName.getMethodName() + ".log");
-    serverStarterRule.withProperty("log-file", logFile.getAbsolutePath())
-        .withProperty("log-level", "debug").startServer();
+    serverStarterRule.withProperty("log-file", logFile.getAbsolutePath()).startServer();
     internalCache = serverStarterRule.getCache();
   }
 
@@ -107,7 +107,7 @@ public class IndexManagerIntegrationTest {
         .create(regionName);
 
     QueryService queryService = internalCache.getQueryService();
-    queryService.createIndex(indexName, "id", "/" + regionName);
+    queryService.createIndex(indexName, "id", SEPARATOR + regionName);
     IntStream.range(1, entries + 1).forEach(i -> region.put(i, new TestQueryObject(i)));
     waitForIndexUpdaterTask(synchronousMaintenance, region);
 
@@ -144,7 +144,6 @@ public class IndexManagerIntegrationTest {
         .contains(String.format(
             "Updating the Index %s failed. The index is corrupted and marked as invalid.",
             indexName));
-    LogFileAssert.assertThat(logFile).contains("Corrupted key is " + newKey);
   }
 
   @Test
@@ -172,7 +171,6 @@ public class IndexManagerIntegrationTest {
         .contains(String.format(
             "Updating the Index %s failed. The index is corrupted and marked as invalid.",
             indexName));
-    LogFileAssert.assertThat(logFile).contains("Corrupted key is " + existingKey);
   }
 
   @Test
@@ -215,7 +213,6 @@ public class IndexManagerIntegrationTest {
         .contains(String.format(
             "Updating the Index %s failed. The index is corrupted and marked as invalid.",
             indexName));
-    LogFileAssert.assertThat(logFile).contains("Corrupted key is " + existingKey);
   }
 
   private static class TestQueryObject implements Serializable {
