@@ -36,6 +36,7 @@ import org.apache.geode.cache.CacheException;
 import org.apache.geode.cache.RegionDestroyedException;
 import org.apache.geode.cache.RegionExistsException;
 import org.apache.geode.cache.query.internal.cq.InternalCqQuery;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
 import org.apache.geode.internal.cache.ClientServerObserver;
 import org.apache.geode.internal.cache.ClientServerObserverHolder;
 import org.apache.geode.internal.cache.Conflatable;
@@ -46,7 +47,6 @@ import org.apache.geode.internal.cache.ha.HARegionQueueAttributes;
 import org.apache.geode.internal.cache.ha.HARegionQueueStats;
 import org.apache.geode.internal.logging.log4j.LogMarker;
 import org.apache.geode.internal.serialization.ByteArrayDataInput;
-import org.apache.geode.internal.serialization.Version;
 import org.apache.geode.internal.statistics.StatisticsClock;
 import org.apache.geode.logging.internal.executors.LoggingThread;
 import org.apache.geode.logging.internal.log4j.api.LogService;
@@ -126,7 +126,7 @@ public class MessageDispatcher extends LoggingThread {
       StatisticsClock statisticsClock) throws CacheException {
     super(name);
 
-    this._proxy = proxy;
+    _proxy = proxy;
 
     // Create the event conflator
     // this._eventConflator = new BridgeEventConflator
@@ -139,26 +139,24 @@ public class MessageDispatcher extends LoggingThread {
       ((HAContainerWrapper) proxy._cacheClientNotifier.getHaContainer())
           .putProxy(HARegionQueue.createRegionName(getProxy().getHARegionName()), getProxy());
       boolean createDurableQueue = proxy.proxyID.isDurable();
-      boolean canHandleDelta = (proxy.getClientVersion().compareTo(Version.GFE_61) >= 0)
-          && proxy.getCache().getInternalDistributedSystem().getConfig().getDeltaPropagation()
-          && !(proxy.clientConflation == Handshake.CONFLATION_ON);
+      boolean canHandleDelta =
+          InternalDistributedSystem.getAnyInstance().getConfig().getDeltaPropagation()
+              && !(_proxy.clientConflation == Handshake.CONFLATION_ON);
       if ((createDurableQueue || canHandleDelta) && logger.isDebugEnabled()) {
         logger.debug("Creating a {} subscription queue for {}",
             createDurableQueue ? "durable" : "non-durable",
             proxy.getProxyID());
       }
-      this._messageQueue = HARegionQueue.getHARegionQueueInstance(getProxy().getHARegionName(),
+      _messageQueue = HARegionQueue.getHARegionQueueInstance(getProxy().getHARegionName(),
           getCache(), harq, HARegionQueue.BLOCKING_HA_QUEUE, createDurableQueue,
           proxy._cacheClientNotifier.getHaContainer(), proxy.getProxyID(),
-          this._proxy.clientConflation, this._proxy.isPrimary(), canHandleDelta, statisticsClock);
+          _proxy.clientConflation, _proxy.isPrimary(), canHandleDelta, statisticsClock);
       // Check if interests were registered during HARegion GII.
-      if (this._proxy.hasRegisteredInterested()) {
-        this._messageQueue.setHasRegisteredInterest(true);
+      if (_proxy.hasRegisteredInterested()) {
+        _messageQueue.setHasRegisteredInterest(true);
       }
-    } catch (CancelException e) {
+    } catch (CancelException | RegionExistsException e) {
       throw e;
-    } catch (RegionExistsException ree) {
-      throw ree;
     } catch (Exception e) {
       getCache().getCancelCriterion().checkCancelInProgress(e);
       throw new CacheException(
@@ -170,7 +168,7 @@ public class MessageDispatcher extends LoggingThread {
   }
 
   private CacheClientProxy getProxy() {
-    return this._proxy;
+    return _proxy;
   }
 
   private InternalCache getCache() {
@@ -193,7 +191,7 @@ public class MessageDispatcher extends LoggingThread {
     if (logger.isDebugEnabled()) {
       logger.debug("{}: notified dispatcher to stop", this);
     }
-    this._isStopped = true;
+    _isStopped = true;
     // this.interrupt(); // don't interrupt here. Let close(boolean) do this.
   }
 
@@ -224,13 +222,12 @@ public class MessageDispatcher extends LoggingThread {
     }
 
     // Stay alive until the queue is empty or a number of peeks is reached.
-    List events = null;
     try {
       for (int numberOfPeeks =
           0; numberOfPeeks < CacheClientProxy.MAXIMUM_SHUTDOWN_PEEKS; ++numberOfPeeks) {
         boolean interrupted = Thread.interrupted();
         try {
-          events = this._messageQueue.peek(1, -1);
+          List<?> events = _messageQueue.peek(1, -1);
           if (events == null || events.size() == 0) {
             break;
           }
@@ -263,7 +260,7 @@ public class MessageDispatcher extends LoggingThread {
    * @return whether the dispatcher is stopped
    */
   protected boolean isStopped() {
-    return this._isStopped;
+    return _isStopped;
   }
 
   /**
@@ -273,7 +270,7 @@ public class MessageDispatcher extends LoggingThread {
    * @return the size of the queue
    */
   protected int getQueueSize() {
-    return this._messageQueue == null ? 0 : this._messageQueue.size();
+    return _messageQueue == null ? 0 : _messageQueue.size();
   }
 
   /**
@@ -283,8 +280,8 @@ public class MessageDispatcher extends LoggingThread {
    * @return the size of the queue
    */
   protected int getQueueSizeStat() {
-    if (this._messageQueue != null) {
-      HARegionQueueStats stats = this._messageQueue.getStatistics();
+    if (_messageQueue != null) {
+      HARegionQueueStats stats = _messageQueue.getStatistics();
       return ((int) (stats.getEventsEnqued() - stats.getEventsRemoved()
           - stats.getEventsConflated() - stats.getMarkerEventsConflated()
           - stats.getEventsExpired() - stats.getEventsRemovedByQrm() - stats.getEventsTaken()
@@ -295,7 +292,7 @@ public class MessageDispatcher extends LoggingThread {
 
   protected void drainClientCqEvents(ClientProxyMembershipID clientId,
       InternalCqQuery cqToClose) {
-    this._messageQueue.closeClientCq(clientId, cqToClose);
+    _messageQueue.closeClientCq(clientId, cqToClose);
   }
 
   @Override
@@ -332,7 +329,7 @@ public class MessageDispatcher extends LoggingThread {
   @VisibleForTesting
   protected void runDispatcher() {
     boolean exceptionOccurred = false;
-    this._isStopped = false;
+    _isStopped = false;
 
     if (logger.isDebugEnabled()) {
       logger.debug("{}: Beginning to process events", this);
@@ -341,7 +338,7 @@ public class MessageDispatcher extends LoggingThread {
     ClientMessage clientMessage = null;
     while (!isStopped()) {
       // SystemFailure.checkFailure(); DM's stopper does this
-      if (this._proxy._cache.getCancelCriterion().isCancelInProgress()) {
+      if (_proxy._cache.getCancelCriterion().isCancelInProgress()) {
         break;
       }
       try {
@@ -352,12 +349,12 @@ public class MessageDispatcher extends LoggingThread {
           // reconnecting.
           synchronized (_pausedLock) {
             try {
-              logger.info("available ids = " + this._messageQueue.size() + " , isEmptyAckList ="
-                  + this._messageQueue.isEmptyAckList() + ", peekInitialized = "
-                  + this._messageQueue.isPeekInitialized());
-              while (!this._messageQueue.isEmptyAckList()
-                  && this._messageQueue.isPeekInitialized()) {
-                this._messageQueue.remove();
+              logger.info("available ids = " + _messageQueue.size() + " , isEmptyAckList ="
+                  + _messageQueue.isEmptyAckList() + ", peekInitialized = "
+                  + _messageQueue.isPeekInitialized());
+              while (!_messageQueue.isEmptyAckList()
+                  && _messageQueue.isPeekInitialized()) {
+                _messageQueue.remove();
               }
             } catch (InterruptedException ex) {
               logger.warn("{}: sleep interrupted.", this);
@@ -366,11 +363,11 @@ public class MessageDispatcher extends LoggingThread {
           waitForResumption();
         }
         try {
-          clientMessage = (ClientMessage) this._messageQueue.peek();
+          clientMessage = (ClientMessage) _messageQueue.peek();
         } catch (RegionDestroyedException skipped) {
           break;
         }
-        getStatistics().setQueueSize(this._messageQueue.size());
+        getStatistics().setQueueSize(_messageQueue.size());
         if (isStopped()) {
           break;
         }
@@ -381,13 +378,13 @@ public class MessageDispatcher extends LoggingThread {
           boolean isDispatched = dispatchMessage(clientMessage);
           getStatistics().endMessage(start);
           if (isDispatched) {
-            this._messageQueue.remove();
+            _messageQueue.remove();
             if (clientMessage instanceof ClientMarkerMessageImpl) {
               getProxy().setMarkerEnqueued(false);
             }
           }
         } else {
-          this._messageQueue.remove();
+          _messageQueue.remove();
         }
         clientMessage = null;
       } catch (MessageTooLargeException e) {
@@ -395,7 +392,7 @@ public class MessageDispatcher extends LoggingThread {
       } catch (IOException e) {
         // Added the synchronization below to ensure that exception handling
         // does not occur while stopping the dispatcher and vice versa.
-        synchronized (this._stopDispatchingLock) {
+        synchronized (_stopDispatchingLock) {
           // An IOException occurred while sending a message to the
           // client. If the processor is not already stopped, assume
           // the client is dead and stop processing.
@@ -491,7 +488,7 @@ public class MessageDispatcher extends LoggingThread {
             getStatistics().endMessage(start);
             itr.remove();
           }
-          this._messageQueue.remove();
+          _messageQueue.remove();
         }
       } catch (CancelException e) {
         if (logger.isDebugEnabled()) {
@@ -503,8 +500,7 @@ public class MessageDispatcher extends LoggingThread {
         if ("Broken pipe".equals(e.getMessage())) {
           extraMsg = "Problem caused by broken pipe on socket.";
         } else if (e instanceof RegionDestroyedException) {
-          extraMsg =
-              "Problem caused by message queue being closed.";
+          extraMsg = "Problem caused by message queue being closed.";
         }
         if (extraMsg == null) {
           extraMsg = "Problem caused by: " + e.getMessage();
@@ -537,7 +533,7 @@ public class MessageDispatcher extends LoggingThread {
         }
       }
     } else {
-      this._isStopped = true;
+      _isStopped = true;
     }
 
     // Stop the ServerConnections. This will force the client to
@@ -569,11 +565,8 @@ public class MessageDispatcher extends LoggingThread {
     if (logger.isTraceEnabled(LogMarker.BRIDGE_SERVER_VERBOSE)) {
       logger.trace(LogMarker.BRIDGE_SERVER_VERBOSE, "Dispatching {}", clientMessage);
     }
-    Message message = null;
-
-    // byte[] latestValue =
-    // this._eventConflator.getLatestValue(clientMessage);
 
+    final Message message;
     if (clientMessage instanceof ClientUpdateMessage) {
       byte[] latestValue = (byte[]) ((ClientUpdateMessage) clientMessage).getValue();
       if (logger.isTraceEnabled()) {
@@ -598,7 +591,7 @@ public class MessageDispatcher extends LoggingThread {
       message = clientMessage.getMessage(getProxy(), true /* notify */);
     }
 
-    if (!this._proxy.isPaused()) {
+    if (!_proxy.isPaused()) {
       sendMessage(message);
 
       if (logger.isTraceEnabled()) {
@@ -611,7 +604,7 @@ public class MessageDispatcher extends LoggingThread {
       }
     }
     if (isDispatched) {
-      this._messageQueue.getStatistics().incEventsDispatched();
+      _messageQueue.getStatistics().incEventsDispatched();
     }
     return isDispatched;
   }
@@ -620,13 +613,13 @@ public class MessageDispatcher extends LoggingThread {
     if (message == null) {
       return;
     }
-    this.socketWriteLock.lock();
+    socketWriteLock.lock();
     try {
       message.setComms(getSocket(), getCommBuffer(), getStatistics());
       message.send();
       getProxy().resetPingCounter();
     } finally {
-      this.socketWriteLock.unlock();
+      socketWriteLock.unlock();
     }
     if (logger.isTraceEnabled()) {
       logger.trace("{}: Sent {}", this, message);
@@ -640,9 +633,9 @@ public class MessageDispatcher extends LoggingThread {
    */
   protected void enqueueMessage(Conflatable clientMessage) {
     try {
-      this._messageQueue.put(clientMessage);
-      if (this._proxy.isPaused() && this._proxy.isDurable()) {
-        this._proxy._cacheClientNotifier.statistics.incEventEnqueuedWhileClientAwayCount();
+      _messageQueue.put(clientMessage);
+      if (_proxy.isPaused() && _proxy.isDurable()) {
+        _proxy._cacheClientNotifier.statistics.incEventEnqueuedWhileClientAwayCount();
         if (logger.isDebugEnabled()) {
           logger.debug("{}: Queued message while Durable Client is away {}", this, clientMessage);
         }
@@ -651,7 +644,7 @@ public class MessageDispatcher extends LoggingThread {
       throw e;
     } catch (Exception e) {
       if (!isStopped()) {
-        this._proxy._statistics.incMessagesFailedQueued();
+        _proxy._statistics.incMessagesFailedQueued();
         logger.fatal(
             String.format("%s: Exception occurred while attempting to add message to queue",
                 this),
@@ -667,7 +660,7 @@ public class MessageDispatcher extends LoggingThread {
         logger.debug("{}: Queueing marker message. <{}>. The queue contains {} entries.", this,
             message, getQueueSize());
       }
-      this._messageQueue.put(message);
+      _messageQueue.put(message);
       if (logger.isDebugEnabled()) {
         logger.debug("{}: Queued marker message. The queue contains {} entries.", this,
             getQueueSize());
@@ -701,7 +694,7 @@ public class MessageDispatcher extends LoggingThread {
       logger.warn("Message too large to send to client: {}, {}", clientMessage, e.getMessage());
 
     } catch (IOException e) {
-      synchronized (this._stopDispatchingLock) {
+      synchronized (_stopDispatchingLock) {
         // Pause or unregister proxy
         if (!isStopped() && !getProxy().isPaused()) {
           logger.fatal(String.format("%s : An unexpected Exception occurred", this),
@@ -717,13 +710,13 @@ public class MessageDispatcher extends LoggingThread {
   }
 
   protected void waitForResumption() throws InterruptedException {
-    synchronized (this._pausedLock) {
+    synchronized (_pausedLock) {
       logger.info("{} : Pausing processing", this);
       if (!getProxy().isPaused()) {
         return;
       }
       while (getProxy().isPaused()) {
-        this._pausedLock.wait();
+        _pausedLock.wait();
       }
       // Fix for #48571
       _messageQueue.clearPeekedIDs();
@@ -734,29 +727,28 @@ public class MessageDispatcher extends LoggingThread {
     logger.info("{} : Resuming processing", this);
 
     // Notify thread to resume
-    this._pausedLock.notifyAll();
+    _pausedLock.notifyAll();
   }
 
   protected Object deserialize(byte[] serializedBytes) {
     Object deserializedObject = serializedBytes;
     // This is a debugging method so ignore all exceptions like
     // ClassNotFoundException
-    try {
-      ByteArrayDataInput dis = new ByteArrayDataInput(serializedBytes);
+    try (ByteArrayDataInput dis = new ByteArrayDataInput(serializedBytes)) {
       deserializedObject = DataSerializer.readObject(dis);
-    } catch (Exception e) {
+    } catch (Exception ignore) {
     }
     return deserializedObject;
   }
 
   protected void initializeTransients() {
-    while (!this._messageQueue.isEmptyAckList() && this._messageQueue.isPeekInitialized()) {
+    while (!_messageQueue.isEmptyAckList() && _messageQueue.isPeekInitialized()) {
       try {
-        this._messageQueue.remove();
+        _messageQueue.remove();
       } catch (InterruptedException e) {
         e.printStackTrace();
       }
     }
-    this._messageQueue.initializeTransients();
+    _messageQueue.initializeTransients();
   }
 }
