@@ -154,6 +154,14 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
     this.threadMonitoring = tMonitoring;
   }
 
+  public void setExpectedReceiverUniqueId(String uniqueId) {
+    this.sender.setExpectedReceiverUniqueId(uniqueId);
+  }
+
+  public String getExpectedReceiverUniqueId() {
+    return this.sender.getExpectedReceiverUniqueId();
+  }
+
   public Object getRunningStateLock() {
     return runningStateLock;
   }
@@ -163,10 +171,16 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
     return getQueue().size();
   }
 
-  protected abstract void initializeMessageQueue(String id);
+  protected abstract void initializeMessageQueue(String id, boolean cleanQueues);
+
+  public void enqueueEvent(EnumListenerEvent operation, EntryEvent event,
+      Object substituteValue) throws IOException, CacheException {
+    enqueueEvent(operation, event, substituteValue, false);
+  }
 
   public abstract void enqueueEvent(EnumListenerEvent operation, EntryEvent event,
-      Object substituteValue) throws IOException, CacheException;
+      Object substituteValue, boolean isLastEventInTransaction) throws IOException, CacheException;
+
 
   protected abstract void rebalance();
 
@@ -426,6 +440,7 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
 
     for (;;) {
       if (stopped()) {
+        this.resetLastPeekedEvents = true;
         break;
       }
 
@@ -442,6 +457,7 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
         for (;;) {
           // check before sleeping
           if (stopped()) {
+            this.resetLastPeekedEvents = true;
             if (isDebugEnabled) {
               logger.debug(
                   "GatewaySenderEventProcessor is stopped. Returning without peeking events.");
@@ -654,6 +670,7 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
             }
             // check again, don't do post-processing if we're stopped.
             if (stopped()) {
+              this.resetLastPeekedEvents = true;
               break;
             }
 
@@ -687,7 +704,11 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
                           "During normal processing, unsuccessfully dispatched {} events (batch #{})",
                           conflatedEventsToBeDispatched.size(), getBatchId());
                     }
-                    if (stopped() || resetLastPeekedEvents) {
+                    if (stopped()) {
+                      this.resetLastPeekedEvents = true;
+                      break;
+                    }
+                    if (resetLastPeekedEvents) {
                       break;
                     }
                     try {
@@ -699,7 +720,9 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
                       Thread.currentThread().interrupt();
                     }
                   }
-                  incrementBatchId();
+                  if (!resetLastPeekedEvents) {
+                    incrementBatchId();
+                  }
                 }
               }
             } // unsuccessful batch
@@ -861,15 +884,10 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
           GatewaySenderEventCallbackArgument geCallbackArg = new GatewaySenderEventCallbackArgument(
               event.getRawCallbackArgument(), this.sender.getMyDSId(), allRemoteDSIds);
           event.setCallbackArgument(geCallbackArg);
+          // OFFHEAP: event for pdx type meta data so it should never be off-heap
           GatewaySenderEventImpl pdxSenderEvent =
-              new GatewaySenderEventImpl(EnumListenerEvent.AFTER_UPDATE, event, null); // OFFHEAP:
-                                                                                       // event for
-                                                                                       // pdx type
-                                                                                       // meta data
-                                                                                       // so it
-                                                                                       // should
-                                                                                       // never be
-                                                                                       // off-heap
+              new GatewaySenderEventImpl(EnumListenerEvent.AFTER_UPDATE, event, null, false);
+
           pdxEventsMap.put(typeEntry.getKey(), pdxSenderEvent);
           pdxSenderEventsList.add(pdxSenderEvent);
         }
@@ -1245,6 +1263,10 @@ public abstract class AbstractGatewaySenderEventProcessor extends LoggingThread
       if (this.sender.isPrimary() && this.queue.size() > 0) {
         logger.warn("Destroying GatewayEventDispatcher with actively queued data.");
       }
+      if (resetLastPeekedEvents) {
+        resetLastPeekedEvents();
+        resetLastPeekedEvents = false;
+      }
     } catch (RegionDestroyedException ignore) {
     } catch (CancelException ignore) {
     } catch (CacheException ignore) {
