@@ -14,6 +14,8 @@
  */
 package org.apache.geode.internal.cache.wan.serial;
 
+import static java.util.concurrent.TimeUnit.SECONDS;
+
 import java.io.IOException;
 import java.util.Collections;
 import java.util.Iterator;
@@ -106,17 +108,17 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
 
 
   public SerialGatewaySenderEventProcessor(AbstractGatewaySender sender, String id,
-      ThreadsMonitoring tMonitoring) {
+      ThreadsMonitoring tMonitoring, boolean cleanQueues) {
     super("Event Processor for GatewaySender_" + id, sender, tMonitoring);
-
-    this.unprocessedEvents = new LinkedHashMap<EventID, EventWrapper>();
-    this.unprocessedTokens = new LinkedHashMap<EventID, Long>();
-
-    initializeMessageQueue(id);
+    synchronized (this.unprocessedEventsLock) {
+      initializeMessageQueue(id, cleanQueues);
+      this.unprocessedEvents = new LinkedHashMap<EventID, EventWrapper>();
+      this.unprocessedTokens = new LinkedHashMap<EventID, Long>();
+    }
   }
 
   @Override
-  protected void initializeMessageQueue(String id) {
+  protected void initializeMessageQueue(String id, boolean cleanQueues) {
     // Create the region name
     StringBuffer regionNameBuffer = new StringBuffer();
     regionNameBuffer.append(id).append("_SERIAL_GATEWAY_SENDER_QUEUE");
@@ -128,7 +130,7 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
       initializeListenerExecutor();
     }
     // Create the region queue
-    this.queue = new SerialGatewaySenderQueue(sender, regionName, listener);
+    this.queue = new SerialGatewaySenderQueue(sender, regionName, listener, cleanQueues);
 
     if (logger.isDebugEnabled()) {
       logger.debug("Created queue: {}", this.queue);
@@ -393,8 +395,8 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
    * Add the input object to the event queue
    */
   @Override
-  public void enqueueEvent(EnumListenerEvent operation, EntryEvent event, Object substituteValue)
-      throws IOException, CacheException {
+  public void enqueueEvent(EnumListenerEvent operation, EntryEvent event, Object substituteValue,
+      boolean isLastEventInTransaction) throws IOException, CacheException {
     // There is a case where the event is serialized for processing. The
     // region is not
     // serialized along with the event since it is a transient field. I
@@ -425,7 +427,8 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
               ((EntryEventImpl) event).isConcurrencyConflict() && !event.isOriginRemote();
           if (!(isUpdateVersionStamp || isCME_And_NotOriginRemote)) {
             senderEvent =
-                new GatewaySenderEventImpl(operation, event, substituteValue, false);
+                new GatewaySenderEventImpl(operation, event, substituteValue, false,
+                    isLastEventInTransaction);
             handleSecondaryEvent(senderEvent);
           }
         }
@@ -439,7 +442,9 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
         waitForFailoverCompletion();
       }
       // If it is, create and enqueue an initialized GatewayEventImpl
-      senderEvent = new GatewaySenderEventImpl(operation, event, substituteValue); // OFFHEAP ok
+      senderEvent =
+          new GatewaySenderEventImpl(operation, event, substituteValue, isLastEventInTransaction); // OFFHEAP
+                                                                                                   // ok
 
       boolean queuedEvent = false;
       try {
@@ -603,7 +608,7 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
       my_executor.execute(new Runnable() {
         @Override
         public void run() {
-          basicHandlePrimaryDestroy(gatewayEvent.getEventId());
+          basicHandlePrimaryDestroy(gatewayEvent.getEventId(), false);
         }
       });
     }
@@ -613,7 +618,8 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
    * Just remove the event from the unprocessed events map if it is present. This method added to
    * fix bug 37603
    */
-  protected boolean basicHandlePrimaryDestroy(final EventID eventId) {
+  protected boolean basicHandlePrimaryDestroy(final EventID eventId,
+      boolean addToUnprocessedTokens) {
     if (this.sender.isPrimary()) {
       // no need to do anything if we have become the primary
       return false;
@@ -621,6 +627,11 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
     GatewaySenderStats statistics = this.sender.getStatistics();
     // Get the event from the map
     synchronized (unprocessedEventsLock) {
+      // If handleFailover() acquired the lock hence double checking
+      if (this.sender.isPrimary()) {
+        // no need to do anything if we have become the primary
+        return false;
+      }
       if (this.unprocessedEvents == null) {
         return false;
       }
@@ -630,6 +641,18 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
         ew.event.release();
         statistics.incUnprocessedEventsRemovedByPrimary();
         return true;
+      } else if (addToUnprocessedTokens) {
+        // Secondary event may not have arrived
+        if (logger.isTraceEnabled()) {
+          logger.trace("{}: fromPrimary destroy event {} : added to unprocessed token map",
+              sender.getId(), eventId);
+        }
+        Long mapValue =
+            System.currentTimeMillis() + AbstractGatewaySender.TOKEN_TIMEOUT;
+        Long oldv = this.unprocessedTokens.put(eventId, mapValue);
+        if (oldv == null) {
+          statistics.incUnprocessedTokensAddedByPrimary();
+        }
       }
     }
     return false;
@@ -643,6 +666,11 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
     GatewaySenderStats statistics = this.sender.getStatistics();
     // Get the event from the map
     synchronized (unprocessedEventsLock) {
+      // If handleFailover() acquired the lock hence double checking
+      if (this.sender.isPrimary()) {
+        // no need to do anything if we have become the primary
+        return;
+      }
       if (this.unprocessedEvents == null) {
         return;
       }
@@ -658,13 +686,10 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
         }
         {
           Long mapValue =
-              Long.valueOf(System.currentTimeMillis() + AbstractGatewaySender.TOKEN_TIMEOUT);
+              System.currentTimeMillis() + AbstractGatewaySender.TOKEN_TIMEOUT;
           Long oldv = this.unprocessedTokens.put(gatewayEvent.getEventId(), mapValue);
           if (oldv == null) {
             statistics.incUnprocessedTokensAddedByPrimary();
-          } else {
-            // its ok for oldv to be non-null
-            // this shouldn't happen anymore @todo add an assertion here
           }
         }
       } else {
@@ -819,7 +844,8 @@ public class SerialGatewaySenderEventProcessor extends AbstractGatewaySenderEven
    */
   private void initializeListenerExecutor() {
     this.executor =
-        LoggingExecutors.newFixedThreadPoolWithTimeout("Queued Gateway Listener Thread", 1, 120);
+        LoggingExecutors.newFixedThreadPoolWithTimeout(1, 120, SECONDS,
+            "Queued Gateway Listener Thread");
   }
 
   private void shutdownListenerExecutor() {
