@@ -15,6 +15,9 @@
 
 package org.apache.geode.test.junit.rules;
 
+import static org.apache.geode.distributed.ConfigurationProperties.HTTP_SERVICE_PORT;
+import static org.apache.geode.distributed.ConfigurationProperties.JMX_MANAGER_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPorts;
 import static org.apache.geode.test.junit.rules.MemberStarterRule.getSSLProperties;
 
 import java.io.File;
@@ -28,12 +31,11 @@ import org.junit.rules.TemporaryFolder;
 import org.apache.geode.distributed.ConfigurationProperties;
 import org.apache.geode.distributed.LocatorLauncher;
 import org.apache.geode.test.junit.rules.serializable.SerializableExternalResource;
-import org.apache.geode.test.junit.rules.serializable.SerializableTemporaryFolder;
 
 public class LocatorLauncherStartupRule extends SerializableExternalResource {
   private LocatorLauncher launcher;
-  private final TemporaryFolder temp = new SerializableTemporaryFolder();
-  private final Properties properties = new Properties();
+  private final TemporaryFolder temp = new TemporaryFolder();
+  private final Properties properties = defaultProperties();
   private boolean autoStart;
   private UnaryOperator<LocatorLauncher.Builder> builderOperator;
 
@@ -108,4 +110,15 @@ public class LocatorLauncherStartupRule extends SerializableExternalResource {
     }
     temp.delete();
   }
+
+  /**
+   * By default, assign available HTTP and JMX ports.
+   */
+  private static Properties defaultProperties() {
+    Properties props = new Properties();
+    int[] ports = getRandomAvailableTCPPorts(2);
+    props.setProperty(HTTP_SERVICE_PORT, String.valueOf(ports[0]));
+    props.setProperty(JMX_MANAGER_PORT, String.valueOf(ports[1]));
+    return props;
+  }
 }
