@@ -14,6 +14,7 @@
  */
 package org.apache.geode.experimental.driver;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_CIPHERS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_ENABLED_COMPONENTS;
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_KEYSTORE;
@@ -25,8 +26,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.SSL_TRUSTSTOR
 import static org.apache.geode.distributed.ConfigurationProperties.SSL_TRUSTSTORE_PASSWORD;
 import static org.apache.geode.internal.Assert.assertTrue;
 import static org.apache.geode.test.util.ResourceUtils.createTempFileFromResource;
-import static org.hamcrest.Matchers.anyOf;
-import static org.hamcrest.Matchers.instanceOf;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.junit.Assert.assertEquals;
 
 import java.io.IOException;
@@ -43,7 +43,6 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.contrib.java.lang.system.RestoreSystemProperties;
 import org.junit.experimental.categories.Category;
-import org.junit.rules.ExpectedException;
 
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.CacheFactory;
@@ -59,9 +58,6 @@ public class SSLTest {
   @Rule
   public RestoreSystemProperties restoreSystemProperties = new RestoreSystemProperties();
 
-  @Rule
-  public ExpectedException expectedException = ExpectedException.none();
-
   private final String DEFAULT_KEY_STORE =
       createTempFileFromResource(SSLTest.class, "default.keystore").getAbsolutePath();
   private final String SERVER_KEY_STORE =
@@ -133,8 +129,8 @@ public class SSLTest {
     // using TLSv1.2 specifically so that in jdk11 (by default using TLSv1.3) this won't take
     // too long to finish.
     startLocator(SERVER_KEY_STORE, SERVER_TRUST_STORE, true, "TLSv1.2", "any");
-    expectedException.expect(IOException.class);
-    driver = new DriverFactory().addLocator("localhost", locatorPort).create();
+    assertThatThrownBy(() -> new DriverFactory().addLocator("localhost", locatorPort).create())
+        .isInstanceOf(IOException.class);
   }
 
   @Test
@@ -144,7 +140,7 @@ public class SSLTest {
     driver = new DriverFactory().addLocator("localhost", locatorPort)
         .setTrustStorePath(DEFAULT_KEY_STORE).setKeyStorePath(DEFAULT_KEY_STORE).create();
     Set<String> regionsOnServer = driver.getRegionNames();
-    assertEquals(Collections.singleton("/region"), regionsOnServer);
+    assertEquals(Collections.singleton(SEPARATOR + "region"), regionsOnServer);
     assertTrue(driver.isConnected());
   }
 
@@ -152,10 +148,10 @@ public class SSLTest {
   public void driverCannotConnectWithBogusClientKeystore() throws Exception {
     startLocator(DEFAULT_KEY_STORE, DEFAULT_KEY_STORE, true, "any", "any");
     startServer();
-    expectedException
-        .expect(anyOf(instanceOf(SSLException.class), instanceOf(SocketException.class)));
-    driver = new DriverFactory().addLocator("localhost", locatorPort)
-        .setTrustStorePath(CLIENT_TRUST_STORE).setKeyStorePath(BOGUSCLIENT_KEY_STORE).create();
+
+    assertThatThrownBy(() -> new DriverFactory().addLocator("localhost", locatorPort)
+        .setTrustStorePath(CLIENT_TRUST_STORE).setKeyStorePath(BOGUSCLIENT_KEY_STORE).create())
+            .isInstanceOfAny(SSLException.class, SocketException.class);
   }
 
   @Test
@@ -164,9 +160,10 @@ public class SSLTest {
     // too long to finish.
     startLocator(BOGUSSERVER_KEY_STORE, SERVER_TRUST_STORE, true, "TLSv1.2", "any");
     startServer();
-    expectedException.expect(SSLException.class);
-    driver = new DriverFactory().addLocator("localhost", locatorPort)
-        .setTrustStorePath(CLIENT_TRUST_STORE).setKeyStorePath(CLIENT_KEY_STORE).create();
+
+    assertThatThrownBy(() -> new DriverFactory().addLocator("localhost", locatorPort)
+        .setTrustStorePath(CLIENT_TRUST_STORE).setKeyStorePath(CLIENT_KEY_STORE).create())
+            .isInstanceOf(SSLException.class);
   }
 
   @Test
@@ -176,18 +173,18 @@ public class SSLTest {
     driver = new DriverFactory().addLocator("localhost", locatorPort)
         .setTrustStorePath(DEFAULT_KEY_STORE).create();
     Set<String> regionsOnServer = driver.getRegionNames();
-    assertEquals(Collections.singleton("/region"), regionsOnServer);
+    assertEquals(Collections.singleton(SEPARATOR + "region"), regionsOnServer);
     assertTrue(driver.isConnected());
   }
 
   @Test
   public void driverCannotConnectIfProtocolsMismatch() throws Exception {
-    startLocator(SERVER_KEY_STORE, SERVER_TRUST_STORE, true, "TLSv1.3", "any");
+    startLocator(SERVER_KEY_STORE, SERVER_TRUST_STORE, true, "TLSv1.1", "any");
     startServer();
-    expectedException.expect(SSLException.class);
-    driver = new DriverFactory().addLocator("localhost", locatorPort)
+
+    assertThatThrownBy(() -> new DriverFactory().addLocator("localhost", locatorPort)
         .setTrustStorePath(CLIENT_TRUST_STORE).setKeyStorePath(CLIENT_KEY_STORE)
-        .setProtocols("TLSv1.2").create();
+        .setProtocols("TLSv1.2").create()).isInstanceOf(SSLException.class);
   }
 
   @Test
@@ -195,9 +192,9 @@ public class SSLTest {
     startLocator(SERVER_KEY_STORE, SERVER_TRUST_STORE, true, "any",
         "TLS_DHE_DSS_WITH_AES_128_CBC_SHA256");
     startServer();
-    expectedException.expect(SSLException.class);
-    driver = new DriverFactory().addLocator("localhost", locatorPort)
+
+    assertThatThrownBy(() -> new DriverFactory().addLocator("localhost", locatorPort)
         .setTrustStorePath(CLIENT_TRUST_STORE).setKeyStorePath(CLIENT_KEY_STORE)
-        .setCiphers("TLS_DHE_DSS_WITH_AES_128_CBC_SHA").create();
+        .setCiphers("TLS_DHE_DSS_WITH_AES_128_CBC_SHA").create()).isInstanceOf(SSLException.class);
   }
 }
