@@ -14,8 +14,6 @@
  */
 package org.apache.geode.codeAnalysis;
 
-import static org.apache.geode.distributed.ConfigurationProperties.SERIALIZABLE_OBJECT_FILTER;
-import static org.apache.geode.distributed.ConfigurationProperties.VALIDATE_SERIALIZABLE_OBJECTS;
 import static org.assertj.core.api.Assertions.fail;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
@@ -28,17 +26,15 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InvalidClassException;
 import java.io.Serializable;
-import java.io.UncheckedIOException;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
-import java.nio.file.Path;
-import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.ServiceLoader;
 import java.util.Set;
 
 import org.junit.Before;
@@ -50,11 +46,14 @@ import org.apache.geode.DataSerializable;
 import org.apache.geode.DataSerializer;
 import org.apache.geode.codeAnalysis.decode.CompiledClass;
 import org.apache.geode.codeAnalysis.decode.CompiledField;
+import org.apache.geode.distributed.ConfigurationProperties;
+import org.apache.geode.distributed.internal.DistributedSystemService;
+import org.apache.geode.distributed.internal.DistributionConfig;
 import org.apache.geode.distributed.internal.DistributionConfigImpl;
 import org.apache.geode.internal.InternalDataSerializer;
 import org.apache.geode.internal.serialization.BufferDataOutputStream;
 import org.apache.geode.internal.serialization.DataSerializableFixedID;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.pdx.internal.TypeRegistry;
 import org.apache.geode.test.junit.categories.SerializationTest;
 import org.apache.geode.unsafe.internal.sun.reflect.ReflectionFactory;
@@ -63,82 +62,54 @@ import org.apache.geode.unsafe.internal.sun.reflect.ReflectionFactory;
  * This subclass of AbstractAnalyzeSerializablesTestBase uses DataSerializer and
  * InternalDataSerializer. It also performs initialization of the Geode TypeRegistry
  */
-@Category(SerializationTest.class)
-public abstract class AnalyzeSerializablesJUnitTestBase
-    extends AnalyzeDataSerializablesJUnitTestBase {
+@Category({SerializationTest.class})
+public abstract class AnalyzeSerializablesJUnitTestBase extends
+    AnalyzeDataSerializablesJUnitTestBase {
+  protected static final String ACTUAL_SERIALIZABLES_DAT = "actualSerializables.dat";
 
-  private static final String ACTUAL_SERIALIZABLES_DAT = "actualSerializables.dat";
-
-  private final String expectedSerializablesFileName =
+  protected String expectedSerializablesFileName =
       "sanctioned-" + getModuleName() + "-serializables.txt";
+  protected List<ClassAndVariableDetails> expectedSerializables;
 
-  protected final List<ClassAndVariableDetails> expectedSerializables = new ArrayList<>();
 
   @Before
   public void setUp() throws Exception {
     TypeRegistry.init();
   }
 
+  @Override
+  protected Class getModuleClass() {
+    // subclasses should override this if their sanctioned-serializables.txt file is not
+    // in org.apache.geode.internal
+    return InternalDataSerializer.class;
+  }
+
+
   @Test
   public void testSerializables() throws Exception {
-    System.out.println(testName.getMethodName() + " starting");
+    System.out.println(this.testName.getMethodName() + " starting");
     findClasses();
     loadExpectedSerializables();
 
     File actualSerializablesFile = createEmptyFile(ACTUAL_SERIALIZABLES_DAT);
-    System.out.println(testName.getMethodName() + " actualSerializablesFile="
+    System.out.println(this.testName.getMethodName() + " actualSerializablesFile="
         + actualSerializablesFile.getAbsolutePath());
 
     List<ClassAndVariables> actualSerializables = findSerializables();
     CompiledClassUtils.storeClassesAndVariables(actualSerializables, actualSerializablesFile);
 
     String diff = CompiledClassUtils
-        .diffSortedClassesAndVariables(expectedSerializables, actualSerializables);
+        .diffSortedClassesAndVariables(this.expectedSerializables, actualSerializables);
     if (!diff.isEmpty()) {
       System.out.println(
           "++++++++++++++++++++++++++++++testSerializables found discrepancies++++++++++++++++++++++++++++++++++++");
       System.out.println(diff);
-
-      String codeAnalysisPackageDir = getPackageDirForClass(getClass());
-      Path excludedClassesSourceFile = INTEGRATION_TEST_RESOURCES_SOURCE_ROOT
-          .resolve(codeAnalysisPackageDir)
-          .resolve(EXCLUDED_CLASSES_TXT);
-
-      String failureMessage = getModuleClass()
-          .map(clazz -> failWithServiceMessage(
-              actualSerializablesFile, diff, excludedClassesSourceFile, clazz))
-          .orElse(failWithoutServiceMessage(
-              diff, excludedClassesSourceFile));
-
-      fail(failureMessage);
+      fail(diff + FAIL_MESSAGE, getSrcPathFor(getResourceAsFile(EXCLUDED_CLASSES_TXT)),
+          actualSerializablesFile.getAbsolutePath(),
+          this.expectedSerializablesFileName);
     }
   }
 
-  private String failWithServiceMessage(File actualSerializablesFile,
-      String diff,
-      Path excludedClassesSourceFile,
-      Class<?> serviceClass) {
-    Path sanctionedSerializablesSourceFile =
-        getSanctionedSerializablesSourceFileForServiceClass(serviceClass);
-    return String.format(diff + FAIL_MESSAGE,
-        excludedClassesSourceFile,
-        actualSerializablesFile.getAbsolutePath(),
-        sanctionedSerializablesSourceFile);
-  }
-
-  private String failWithoutServiceMessage(String diff,
-      Path excludedClassesSourceFile) {
-    return String.format(diff + FAIL_MESSAGE_NO_SERVICE,
-        excludedClassesSourceFile);
-  }
-
-  private Path getSanctionedSerializablesSourceFileForServiceClass(Class<?> serviceClass) {
-    String moduleServicePackageDir = getPackageDirForClass(serviceClass);
-    return MAIN_RESOURCES_SOURCE_ROOT
-        .resolve(moduleServicePackageDir)
-        .resolve(expectedSerializablesFileName);
-  }
-
   @Test
   public void testSanctionedClassesExistAndDoDeserialize() throws Exception {
     loadExpectedSerializables();
@@ -154,7 +125,7 @@ public abstract class AnalyzeSerializablesJUnitTestBase
       String className = details.className.replaceAll("/", ".");
       System.out.println("testing class " + details.className);
 
-      Class<?> sanctionedClass = null;
+      Class sanctionedClass = null;
       try {
         sanctionedClass = Class.forName(className);
       } catch (ClassNotFoundException cnf) {
@@ -162,10 +133,6 @@ public abstract class AnalyzeSerializablesJUnitTestBase
             + expectedSerializablesFileName);
       }
 
-      if (ignoreClass(sanctionedClass)) {
-        continue;
-      }
-
       assertTrue(
           sanctionedClass.getName() + " is not Serializable and should be removed from "
               + expectedSerializablesFileName,
@@ -198,9 +165,8 @@ public abstract class AnalyzeSerializablesJUnitTestBase
       try {
         boolean isThrowable = Throwable.class.isAssignableFrom(sanctionedClass);
 
-        Constructor<?> constructor =
-            isThrowable ? sanctionedClass.getDeclaredConstructor(String.class)
-                : sanctionedClass.getDeclaredConstructor((Class<?>[]) null);
+        Constructor constructor = isThrowable ? sanctionedClass.getDeclaredConstructor(String.class)
+            : sanctionedClass.getDeclaredConstructor((Class<?>[]) null);
         constructor.setAccessible(true);
         sanctionedInstance =
             isThrowable ? constructor.newInstance("test throwable") : constructor.newInstance();
@@ -211,7 +177,7 @@ public abstract class AnalyzeSerializablesJUnitTestBase
       }
       try {
         Class<?> superClass = sanctionedClass;
-        Constructor<?> constructor = null;
+        Constructor constructor = null;
         if (Externalizable.class.isAssignableFrom(sanctionedClass)) {
           Constructor<?> cons = sanctionedClass.getDeclaredConstructor((Class<?>[]) null);
           cons.setAccessible(true);
@@ -229,9 +195,9 @@ public abstract class AnalyzeSerializablesJUnitTestBase
               .newConstructorForSerialization(sanctionedClass, constructor);
         }
         sanctionedInstance = constructor.newInstance();
-      } catch (Exception e) {
+      } catch (Exception e2) {
         throw new AssertionError("Unable to instantiate " + className + " - please move it from "
-            + expectedSerializablesFileName + " to excludedClasses.txt", e);
+            + expectedSerializablesFileName + " to excludedClasses.txt", e2);
       }
       serializeAndDeserializeSanctionedObject(sanctionedInstance);
     }
@@ -273,26 +239,21 @@ public abstract class AnalyzeSerializablesJUnitTestBase
   }
 
   public void loadExpectedSerializables() throws Exception {
-    getModuleClass().ifPresent(this::loadSanctionedSerializables);
-  }
-
-  private void loadSanctionedSerializables(Class<?> clazz) {
     try (InputStream expectedSerializablesStream =
-        getResourceAsStream(clazz, expectedSerializablesFileName)) {
+        getResourceAsStream(getModuleClass(), expectedSerializablesFileName)) {
       // the expectedSerializablesStream will be automatically closed when we exit this block
-      expectedSerializables.addAll(
-          CompiledClassUtils.loadClassesAndVariables(expectedSerializablesStream));
-    } catch (IOException e) {
-      throw new UncheckedIOException(e);
+      this.expectedSerializables =
+          CompiledClassUtils.loadClassesAndVariables(expectedSerializablesStream);
     }
   }
 
+
   private List<ClassAndVariables> findSerializables() throws IOException {
     List<ClassAndVariables> result = new ArrayList<>(2000);
     List<String> excludedClasses = loadExcludedClasses(getResourceAsFile(EXCLUDED_CLASSES_TXT));
     System.out.println("excluded classes are " + excludedClasses);
     Set<String> setOfExclusions = new HashSet<>(excludedClasses);
-    for (Map.Entry<String, CompiledClass> entry : classes.entrySet()) {
+    for (Map.Entry<String, CompiledClass> entry : this.classes.entrySet()) {
       CompiledClass compiledClass = entry.getValue();
       if (setOfExclusions.contains(compiledClass.fullyQualifiedName())) {
         System.out.println("excluding class " + compiledClass.fullyQualifiedName());
@@ -315,13 +276,15 @@ public abstract class AnalyzeSerializablesJUnitTestBase
     return result;
   }
 
+
+
   @Override
   protected void initializeSerializationService() {
     Properties properties = new Properties();
-    properties.setProperty(VALIDATE_SERIALIZABLE_OBJECTS, "true");
-    properties.setProperty(SERIALIZABLE_OBJECT_FILTER, "!*");
-
-    InternalDataSerializer.initializeSerializationFilter(new DistributionConfigImpl(properties));
+    properties.put(ConfigurationProperties.VALIDATE_SERIALIZABLE_OBJECTS, "true");
+    properties.put(ConfigurationProperties.SERIALIZABLE_OBJECT_FILTER, "!*");
+    DistributionConfig distributionConfig = new DistributionConfigImpl(properties);
+    InternalDataSerializer.initialize(distributionConfig, initializeServices());
   }
 
   @Override
@@ -337,13 +300,11 @@ public abstract class AnalyzeSerializablesJUnitTestBase
     DataSerializer.writeObject(object, outputStream);
   }
 
+
   private void serializeAndDeserializeSanctionedObject(Object object) throws Exception {
-    BufferDataOutputStream outputStream = new BufferDataOutputStream(Version.CURRENT);
+    BufferDataOutputStream outputStream = new BufferDataOutputStream(KnownVersion.CURRENT);
     try {
       serializeObject(object, outputStream);
-    } catch (RemoteException e) {
-      fail(object.getClass().getName() +
-          " is a java.rmi.server.RemoteObject which is not supported by AnalyzeSerializables", e);
     } catch (IOException e) {
       // some classes, such as BackupLock, are Serializable because the extend something
       // like ReentrantLock but we never serialize them & it doesn't work to try to do so
@@ -358,7 +319,18 @@ public abstract class AnalyzeSerializablesJUnitTestBase
     }
   }
 
-  private boolean isSerializableAndNotDataSerializable(CompiledClass compiledClass) {
+  private List<DistributedSystemService> initializeServices() {
+    ServiceLoader<DistributedSystemService> loader =
+        ServiceLoader.load(DistributedSystemService.class);
+    List<DistributedSystemService> services = new ArrayList<>();
+    for (DistributedSystemService service : loader) {
+      services.add(service);
+    }
+    return services;
+  }
+
+
+  public boolean isSerializableAndNotDataSerializable(CompiledClass compiledClass) {
     // these classes throw exceptions or log ugly messages when you try to load them
     // in junit
     String name = compiledClass.fullyQualifiedName().replace('/', '.');
@@ -367,7 +339,7 @@ public abstract class AnalyzeSerializablesJUnitTestBase
       return false;
     }
     try {
-      Class<?> realClass = Class.forName(name);
+      Class realClass = Class.forName(name);
       return Serializable.class.isAssignableFrom(realClass)
           && !DataSerializable.class.isAssignableFrom(realClass)
           && !DataSerializableFixedID.class.isAssignableFrom(realClass);
@@ -381,7 +353,6 @@ public abstract class AnalyzeSerializablesJUnitTestBase
     return false;
   }
 
-  private static String getPackageDirForClass(Class<?> theClass) {
-    return theClass.getPackage().getName().replace(".", File.separator);
-  }
+
+
 }
