@@ -57,7 +57,7 @@ public class MembershipDependenciesJUnitTest {
               .or(resideInAPackage("org.apache.geode.distributed.internal.tcpserver.."))
               .or(resideInAPackage("org.apache.geode.internal.inet.."))
               .or(resideInAPackage("org.apache.geode.internal.lang.."))
-              .or(resideInAPackage("org.apache.geode.codeAnalysis.."))
+              .or(resideInAPackage("org.apache.geode.annotations.."))
 
               .or(not(resideInAPackage("org.apache.geode..")))
               .or(type(AvailablePortHelper.class))
