@@ -15,7 +15,6 @@
 package org.apache.geode;
 
 import static java.util.Arrays.asList;
-import static java.util.Collections.emptySet;
 import static java.util.Collections.singletonList;
 
 import java.io.ByteArrayInputStream;
@@ -23,6 +22,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.DataInputStream;
 import java.io.DataOutputStream;
 import java.lang.reflect.Constructor;
+import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Properties;
@@ -40,7 +40,7 @@ import org.apache.geode.internal.InternalDataSerializer;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.tier.sockets.OldClientSupportService;
 import org.apache.geode.internal.serialization.ByteArrayDataInput;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.serialization.VersionedDataInputStream;
 import org.apache.geode.internal.serialization.VersionedDataOutputStream;
 import org.apache.geode.test.dunit.cache.internal.JUnit4CacheTestCase;
@@ -74,7 +74,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
   }
 
   @Test
-  public void cacheInstallsOldClientSupportServiceProvider() throws Exception {
+  public void cacheInstallsOldClientSupportServiceProvider() {
     Assert.assertNotNull(((InternalCache) myCache).getService(OldClientSupportService.class));
   }
 
@@ -84,7 +84,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
    * EmtpyRegionFunctionException.
    */
   @Test
-  public void testConversionOfThrowablesForOldClients() throws Exception {
+  public void testConversionOfThrowablesForOldClients() {
     List<Throwable> problems = new LinkedList<>();
 
     for (String geodeClassName : allGeodeThrowableClasses) {
@@ -93,8 +93,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
       } catch (Exception e) {
         System.out.println("-- failed");
         Exception failure =
-            new Exception("Failed processing " + geodeClassName + ": " + e.toString());
-        failure.initCause(e);
+            new Exception("Failed processing " + geodeClassName + ": " + e.toString(), e);
         problems.add(failure);
       }
     }
@@ -105,10 +104,10 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
   }
 
   @Test
-  public void testConversionOfArrayTypes() throws Exception {
+  public void testConversionOfArrayTypes() {
     OldClientSupportService oldClientSupport = OldClientSupportProvider.getService(myCache);
 
-    Version oldClientVersion = Version.GFE_82;
+    KnownVersion oldClientVersion = KnownVersion.GFE_81;
     VersionedDataOutputStream dout = new VersionedDataOutputStream(
         new HeapDataOutputStream(10, oldClientVersion), oldClientVersion);
 
@@ -133,14 +132,14 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
   }
 
   private void convertThrowable(String geodeClassName) throws Exception {
-    Version oldClientVersion = Version.GFE_82;
+    KnownVersion oldClientVersion = KnownVersion.GFE_81;
     final String comGemstoneGemFire = "com.gemstone.gemfire";
     final int comGemstoneGemFireLength = comGemstoneGemFire.length();
 
     OldClientSupportService oldClientSupport = OldClientSupportProvider.getService(myCache);
 
     System.out.println("checking " + geodeClassName);
-    Class geodeClass = Class.forName(geodeClassName);
+    Class<?> geodeClass = Class.forName(geodeClassName);
     Object geodeObject = instantiate(geodeClass);
     if (geodeObject instanceof Throwable) {
       Throwable geodeThrowable = (Throwable) instantiate(geodeClass);
@@ -154,7 +153,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
   }
 
   private Object instantiate(Class<?> aClass) throws Exception {
-    Constructor<?> c = null;
+    Constructor<?> c;
     try {
       c = aClass.getConstructor();
       return c.newInstance();
@@ -184,7 +183,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
     properties.put(ConfigurationProperties.SERIALIZABLE_OBJECT_FILTER,
         "org.apache.geode.ClientSerializableObjec");
     DistributionConfig config = new DistributionConfigImpl(properties);
-    InternalDataSerializer.initializeSerializationFilter(config, emptySet());
+    InternalDataSerializer.initialize(config, new ArrayList<>());
 
     com.gemstone.gemfire.ClientSerializableObject gemfireObject =
         new com.gemstone.gemfire.ClientSerializableObject();
@@ -199,7 +198,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
     byte[] serializedForm = byteStream.toByteArray();
 
     ByteArrayDataInput byteDataInput = new ByteArrayDataInput();
-    byteDataInput.initialize(serializedForm, Version.GFE_82);
+    byteDataInput.initialize(serializedForm, KnownVersion.GFE_81);
     ClientSerializableObject result = DataSerializer.readObject(byteDataInput);
     Assert.assertEquals("Expected an org.apache.geode exception but found " + result,
         result.getClass().getName().substring(0, "org.apache.geode".length()), "org.apache.geode");
@@ -226,7 +225,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
     byte[] serializedForm = byteStream.toByteArray();
 
     ByteArrayDataInput byteDataInput = new ByteArrayDataInput();
-    byteDataInput.initialize(serializedForm, Version.GFE_82);
+    byteDataInput.initialize(serializedForm, KnownVersion.GFE_81);
     Object result = DataSerializer.readObject(byteDataInput);
     Assert.assertEquals("Expected an org.apache.geode object but found " + result,
         result.getClass().getName().substring(0, "org.apache.geode".length()), "org.apache.geode");
@@ -250,7 +249,7 @@ public class OldClientSupportDUnitTest extends JUnit4CacheTestCase {
     byte[] serializedForm = byteStream.toByteArray();
 
     ByteArrayDataInput byteDataInput = new ByteArrayDataInput();
-    byteDataInput.initialize(serializedForm, Version.GFE_82);
+    byteDataInput.initialize(serializedForm, KnownVersion.GFE_81);
     Object result = DataSerializer.readObject(byteDataInput);
     Assert.assertEquals("Expected an org.apache.geode object but found " + result,
         result.getClass().getName().substring(0, "org.apache.geode".length()), "org.apache.geode");
